/**
 * libSpiff - XSPF playlist handling library
 *
 * Copyright (C) 2006 Sebastian Pipping
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Sebastian Pipping, webmaster@hartwork.org
 */

#ifndef SPIFF_PARSER_H
#define SPIFF_PARSER_H 1



#include "SpiffDefines.h"
#include "SpiffStack.h"
#include <string>
using namespace std;

namespace Spiff {



/*
playlist
	title
	creator
	annotation
	info
	location
	identifier
	image
	date
	license
	attribution
	link
	meta
	extension
	trackList
		track
			location
			identifier
			title
			creator
			annotation
			info
			image
			album
			trackNum
			duration
			link
			meta
			extension
*/



class SpiffPlaylistProps;
class SpiffTrack;
class SpiffCallback;



class SpiffParser {

private:
	XML_Parser parser;
	int depth;
	SpiffStack stack;
	SpiffPlaylistProps * props;
	SpiffTrack * track;
	SpiffCallback * callback;
	basic_string<XML_Char> accum;

public:
	SpiffParser(XML_Char * filename, SpiffCallback * callback);
	void handleStart(const XML_Char * name, const XML_Char ** atts);
	void handleEnd(const XML_Char * name);
	void handleCharacters(const XML_Char * s, int len);

private:
	static void masterStart(void * userData, const XML_Char * name, const XML_Char ** atts);
	static void masterEnd(void * userData, const XML_Char * name);
	static void masterCharacters(void * userData, const XML_Char * s, int len);

};



}

#endif // SPIFF_PARSER_H
